@@ -1,5 +1,6 @@
 import unittest
 
+from . import CacheTestMixin
 from cachetools import LFUCache, lfu_cache
 
 
@@ -13,47 +14,50 @@ def cached_typed(n):
     return n
 
 
-class LFUCacheTest(unittest.TestCase):
+class LFUCacheTest(unittest.TestCase, CacheTestMixin):
 
-    def test_insert(self):
-        cache = LFUCache(maxsize=2)
+    def make_cache(self, maxsize, getsizeof=None):
+        return LFUCache(maxsize, getsizeof)
 
-        cache['a'] = 1
-        cache['a']
-        cache['b'] = 2
-        cache['c'] = 3
+    def test_lfu_insert(self):
+        cache = self.make_cache(maxsize=2)
+
+        cache[1] = 1
+        cache[1]
+        cache[2] = 2
+        cache[3] = 3
 
         self.assertEqual(len(cache), 2)
-        self.assertEqual(cache['a'], 1)
-        self.assertTrue('b' in cache or 'c' in cache)
-        self.assertTrue('b' not in cache or 'c' not in cache)
+        self.assertEqual(cache[1], 1)
+        self.assertTrue(2 in cache or 3 in cache)
+        self.assertTrue(2 not in cache or 3 not in cache)
 
-        cache['d'] = 4
+        cache[4] = 4
         self.assertEqual(len(cache), 2)
-        self.assertEqual(cache['d'], 4)
-        self.assertEqual(cache['a'], 1)
+        self.assertEqual(cache[4], 4)
+        self.assertEqual(cache[1], 1)
 
-    def test_getsizeof(self):
-        cache = LFUCache(maxsize=3, getsizeof=lambda x: x)
+    def test_lfu_getsizeof(self):
+        cache = self.make_cache(maxsize=3, getsizeof=lambda x: x)
 
-        cache['a'] = 1
-        cache['b'] = 2
+        cache[1] = 1
+        cache[2] = 2
 
         self.assertEqual(len(cache), 2)
-        self.assertEqual(cache['a'], 1)
-        self.assertEqual(cache['b'], 2)
+        self.assertEqual(cache[1], 1)
+        self.assertEqual(cache[2], 2)
 
-        cache['c'] = 3
+        cache[3] = 3
 
         self.assertEqual(len(cache), 1)
-        self.assertEqual(cache['c'], 3)
-        self.assertNotIn('a', cache)
-        self.assertNotIn('b', cache)
+        self.assertEqual(cache[3], 3)
+        self.assertNotIn(1, cache)
+        self.assertNotIn(2, cache)
 
         with self.assertRaises(ValueError):
-            cache['d'] = 4
+            cache[4] = 4
         self.assertEqual(len(cache), 1)
-        self.assertEqual(cache['c'], 3)
+        self.assertEqual(cache[3], 3)
 
     def test_decorator(self):
         self.assertEqual(cached(1), 1)
